@@ -14,6 +14,11 @@ import aws_cdk.aws_sns
 import aws_cdk.aws_sqs
 import aws_cdk.core
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-sns-subscriptions", "1.34.0", __name__[0:-6], "aws-sns-subscriptions@1.34.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
